@@ -14,7 +14,8 @@ Usage::
 """
 from typing import IO, Any, Dict, Type, Union
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
+from botocore.response import StreamingBody
 
 from .literals import ContentTypeType, QueryParserType
 from .type_defs import SearchResponseTypeDef, SuggestResponseTypeDef, UploadDocumentsResponseTypeDef
@@ -36,18 +37,25 @@ class Exceptions:
     SearchException: Type[BotocoreClientError]
 
 
-class CloudSearchDomainClient:
+class CloudSearchDomainClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CloudSearchDomainClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#can_paginate)
         """
 
@@ -59,7 +67,9 @@ class CloudSearchDomainClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#generate_presigned_url)
         """
 
@@ -82,20 +92,26 @@ class CloudSearchDomainClient:
         stats: str = None
     ) -> SearchResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
+        Retrieves a list of documents that match the specified search criteria.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#search)
         """
 
     def suggest(self, *, query: str, suggester: str, size: int = None) -> SuggestResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
+        Retrieves autocomplete suggestions for a partial query string.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#suggest)
         """
 
     def upload_documents(
-        self, *, documents: Union[bytes, IO[bytes]], contentType: ContentTypeType
+        self, *, documents: Union[bytes, IO[bytes], StreamingBody], contentType: ContentTypeType
     ) -> UploadDocumentsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.98/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
+        Posts a batch of documents to a search domain for indexing.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.11/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudsearchdomain/client.html#upload_documents)
         """
